@@ -94,7 +94,7 @@ class ResponsePacket(Packet):
         return 'Unknown Error'
 
     def __repr__(self):
-        return f'{self.__class__.__name__}(service={bytes([self.service])!r}, command={self.command!r}, error={self.error!r})'
+        return f'{self.__class__.__name__}(service={bytes([self.service]) if self.service else None!r}, command={self.command!r}, error={self.error!r})'
 
     __str__ = __repr__
 
@@ -128,43 +128,58 @@ class SendUnitDataResponsePacket(ResponsePacket):
         return f'{get_service_status(self.service_status)} - {get_extended_status(self.raw, 48)}'
 
 
-@logged
-class GenericReadResponsePacket(SendUnitDataResponsePacket):
-    def __init__(self, *args, data_format: DataFormatType = None, **kwargs):
-        self.data_format = data_format
-        super().__init__(*args, **kwargs)
+def generic_read_response(connected=True):
+    base_class = SendUnitDataResponsePacket if connected else SendRRDataResponsePacket
 
-    def _parse_reply(self):
-        super()._parse_reply()
-        if self.data_format is None:
-            self.value = self.data
-        else:
-            try:
-                values = {}
-                start = 0
-                for name, typ in self.data_format:
-                    if isinstance(typ, int):
-                        value = self.data[start: start + typ]
-                        start += typ
-                    else:
-                        unpack_func = UNPACK_DATA_FUNCTION[typ]
-                        value = unpack_func(self.data[start:])
-                        if typ == 'SHORT_STRING':
-                            data_size = len(value) + 1
-                        else:
-                            data_size = DATA_FUNCTION_SIZE[typ]
-                        start += data_size
+    @logged
+    class GenericReadResponsePacket(base_class):
+        def __init__(self, *args, data_format: DataFormatType = None, **kwargs):
+            self.data_format = data_format
+            super().__init__(*args, **kwargs)
 
-                    if name:
-                        values[name] = value
-            except Exception as err:
-                self._error = f'Failed to parse reply - {err}'
-                self.value = None
+        def _parse_reply(self):
+            super()._parse_reply()
+            if self.data_format is None:
+                self.value = self.data
             else:
-                self.value = values
+                try:
+                    values = {}
+                    start = 0
+                    for name, typ in self.data_format:
+                        if isinstance(typ, int):
+                            value = self.data[start: start + typ]
+                            start += typ
+                        else:
+                            unpack_func = UNPACK_DATA_FUNCTION[typ]
+                            value = unpack_func(self.data[start:])
+                            if typ == 'SHORT_STRING':
+                                data_size = len(value) + 1
+                            else:
+                                data_size = DATA_FUNCTION_SIZE[typ]
+                            start += data_size
 
-    def __repr__(self):
-        return f'{self.__class__.__name__}(value={_r(self.value)}, error={self.error!r})'
+                        if name:
+                            values[name] = value
+                except Exception as err:
+                    self._error = f'Failed to parse reply - {err}'
+                    self.value = None
+                else:
+                    self.value = values
+
+        def __repr__(self):
+            return f'{self.__class__.__name__}(value={_r(self.value)}, error={self.error!r})'
+
+    return GenericReadResponsePacket
+
+
+def generic_write_response(connected=True):
+    base_class = SendUnitDataResponsePacket if connected else SendRRDataResponsePacket
+
+    @logged
+    class GenericWriteResponsePacket(base_class):
+        ...
+
+    return GenericWriteResponsePacket
 
 
 @logged
@@ -240,9 +255,7 @@ class WriteTagFragmentedServiceResponsePacket(SendUnitDataResponsePacket):
     ...
 
 
-@logged
-class GenericWriteResponsePacket(SendUnitDataResponsePacket):
-    ...
+
 
 
 @logged
